@@ -1,4 +1,4 @@
-from shadow4.syned.shape import SurfaceData
+from syned.beamline.shape import SurfaceData
 from shadow4.beamline.optical_elements.mirrors.s4_mirror import S4MirrorElement, S4Mirror, ElementCoordinates
 
 from shadow4.beamline.s4_optical_element import S4SurfaceDataOpticalElement
