@@ -1,6 +1,4 @@
-from shadow4.syned.beamline_element import BeamlineElement # todo: change when syned upgraded
-# from syned.beamline.beamline_element import BeamlineElement
-
+from syned.beamline.beamline_element import BeamlineElement
 
 class S4BeamlineElement(BeamlineElement):
 
@@ -13,4 +11,6 @@ class S4BeamlineElement(BeamlineElement):
     def info(self):
         return self.get_optical_element().info() + "\n" + self.get_coordinates().info()
 
+    def to_python_code(self, data=None):
+        raise NotImplementedError()
 
