@@ -1,12 +1,12 @@
 import numpy
 import os
 
-from shadow4.syned.shape import Direction, Convexity
-from shadow4.syned.shape import Sphere, SphericalCylinder
-from shadow4.syned.shape import Ellipsoid, EllipticalCylinder
-from shadow4.syned.shape import Hyperboloid, HyperbolicCylinder
-from shadow4.syned.shape import Paraboloid, ParabolicCylinder
-from shadow4.syned.shape import Toroid, Conic, SurfaceData, Plane, Side
+from syned.beamline.shape import Direction, Convexity
+from syned.beamline.shape import Sphere, SphericalCylinder
+from syned.beamline.shape import Ellipsoid, EllipticalCylinder
+from syned.beamline.shape import Hyperboloid, HyperbolicCylinder
+from syned.beamline.shape import Paraboloid, ParabolicCylinder
+from syned.beamline.shape import Toroid, Conic, SurfaceData, Plane, Side
 
 from shadow4.optical_surfaces.s4_conic import S4Conic
 from shadow4.optical_surfaces.s4_mesh import S4Mesh
@@ -46,6 +46,7 @@ class S4PlaneOpticalElement(S4OpticalElement):
     def get_optical_surface_instance(self):
         return S4Conic.initialize_as_plane()
 
+
 class S4CurvedOpticalElement(S4OpticalElement):
 
     def __init__(self,
@@ -337,4 +338,4 @@ class S4AdditiveSurfaceDataOpticalElement(S4CurvedOpticalElement):
         # from srxraylib.plot.gol import plot_surface
         # plot_surface(zadd, x, y, xtitle="x")
         num_mesh.add_to_mesh( zadd )
-        return num_mesh
\ No newline at end of file
+        return num_mesh
