@@ -2,9 +2,30 @@ from syned.storage_ring.light_source import LightSource
 
 class S4LightSource(LightSource):
 
-    def __init__(self, name="Undefined", electron_beam=None, magnetic_structure=None):
+    def __init__(self,
+                 name="Undefined",
+                 electron_beam=None,
+                 magnetic_structure=None,
+                 nrays=5000,
+                 seed=12345,
+                 ):
         super().__init__(name=name, electron_beam=electron_beam, magnetic_structure=magnetic_structure)
 
+        self.__nrays = nrays
+        self.__seed = seed
+
+    def set_nrays(self, nrays):
+        self.__nrays = nrays
+
+    def get_nrays(self):
+        return self.__nrays
+
+    def set_seed(self, seed):
+        self.__seed = seed
+
+    def get_seed(self):
+        return self.__seed
+
     def to_python_code(self, data=None):
         script = ''
         try:
@@ -19,8 +40,8 @@ class S4LightSource(LightSource):
 
 
         script += "\n\n\nfrom shadow4.sources.s4_light_source import S4LightSource"
-        script += "\nlight_source = S4LightSource(name='%s', electron_beam=electron_beam, magnetic_structure=source)" % \
-                                                          (self.get_name())
+        script += "\nlight_source = S4LightSource(name='%s', electron_beam=electron_beam, magnetic_structure=source, nrays=%s, seed=%s)" % \
+                                (self.get_name(), self.get_nrays(), self.get_seed())
         return script
 
     def get_beam(self, **params):
