@@ -4,12 +4,11 @@ It is redundant with source_geometrical
 """
 import numpy
 from shadow4.beam.beam import Beam
+from shadow4.sources.s4_light_source_base import S4LightSourceBase
 
-
-class SourceGaussian(object):
+class SourceGaussian(S4LightSourceBase):
 
     def __init__(self,
-                 number_of_rays,
                  sigmaX,
                  sigmaY,
                  sigmaZ,
@@ -17,10 +16,13 @@ class SourceGaussian(object):
                  sigmaZprime,
                  real_space_center,
                  direction_space_center,
+                 name="Undefined",
+                 nrays=5000,
                  seed=123456,
                  ):
 
-        self._number_of_rays = number_of_rays
+        super().__init__(name=name, nrays=nrays, seed=seed)
+        # self._number_of_rays = number_of_rays
         self._sigmaX = sigmaX
         self._sigmaY = sigmaY
         self._sigmaZ = sigmaZ
@@ -28,7 +30,7 @@ class SourceGaussian(object):
         self._sigmaZprime = sigmaZprime
         self._real_space_center = real_space_center
         self._direction_space_center = direction_space_center
-        self._seed = seed
+        # self._seed = seed
 
         if seed != 0:
             numpy.random.seed(seed)
@@ -36,70 +38,77 @@ class SourceGaussian(object):
 
     @classmethod
     def initialize_from_keywords(cls,
-                 number_of_rays=10000,
                  sigmaX=1.0e-6,
                  sigmaY=1.0e-6,
                  sigmaZ=0.0,
                  sigmaXprime=1e-6,
                  sigmaZprime=1e-6,
                  real_space_center=[0.0,0.0,0.0],
-                 direction_space_center=[0.0,0.0]
-                                 ):
+                 direction_space_center=[0.0,0.0],
+                 nrays=10000,
+                 seed=12345,
+                 ):
         return SourceGaussian(
-                 number_of_rays,
                  sigmaX,
                  sigmaY,
                  sigmaZ,
                  sigmaXprime,
                  sigmaZprime,
                  real_space_center,
-                 direction_space_center)
+                 direction_space_center,
+                 nrays=nrays,
+                 seed=seed)
 
     @classmethod
     def initialize_point_source(cls,
-                 number_of_rays=10000,
                  sigmaXprime=1e-6,
                  sigmaZprime=1e-6,
                  real_space_center=[0.0,0.0,0.0],
-                 direction_space_center=[0.0,0.0] ):
+                 direction_space_center=[0.0,0.0],
+                 nrays=10000,
+                 seed=12345,
+                 ):
 
         return SourceGaussian(
-                 number_of_rays,
                  0.0,
                  0.0,
                  0.0,
                  sigmaXprime,
                  sigmaZprime,
                  real_space_center,
-                 direction_space_center)
+                 direction_space_center,
+                 nrays=nrays,
+                 seed=seed)
 
 
     @classmethod
     def initialize_collimated_source(cls,
-                 number_of_rays=10000,
                  sigmaX=1.0,
                  sigmaY=0.0,
                  sigmaZ=1.0,
                  real_space_center=[0.0,0.0,0.0],
-                 direction_space_center=[0.0,0.0]
-                                 ):
+                 direction_space_center=[0.0,0.0],
+                 nrays = 10000,
+                 seed=12345,
+                 ):
 
         return SourceGaussian(
-                 number_of_rays,
                  sigmaX,
                  sigmaY,
                  sigmaZ,
                  0.0,
                  0.0,
                  real_space_center,
-                 direction_space_center)
+                 direction_space_center,
+                 nrays=nrays,
+                 seed=seed)
 
 
     #
     # getters
     #
     def get_number_of_points(self):
-        return self._number_of_rays
+        return self.get_nrays()
 
     def get_sigmas_real_space(self):
         return self._sigmaX,self._sigmaY,self._sigmaZ
@@ -110,32 +119,32 @@ class SourceGaussian(object):
     def get_arrays_real_space(self):
 
         if self._sigmaX > 0.0:
-            x = numpy.random.normal(self._real_space_center[0],self._sigmaX,self._number_of_rays)
+            x = numpy.random.normal(self._real_space_center[0],self._sigmaX,self.get_number_of_points())
         else:
-            x = numpy.zeros(self._number_of_rays)
+            x = numpy.zeros(self.get_number_of_points())
 
         if self._sigmaY > 0.0:
-            y = numpy.random.normal(self._real_space_center[1],self._sigmaY,self._number_of_rays)
+            y = numpy.random.normal(self._real_space_center[1],self._sigmaY,self.get_number_of_points())
         else:
-            y = numpy.zeros(self._number_of_rays)
+            y = numpy.zeros(self.get_number_of_points())
 
         if self._sigmaZ > 0.0:
-            z = numpy.random.normal(self._real_space_center[2],self._sigmaZ,self._number_of_rays)
+            z = numpy.random.normal(self._real_space_center[2],self._sigmaZ,self.get_number_of_points())
         else:
-            z = numpy.zeros(self._number_of_rays)
+            z = numpy.zeros(self.get_number_of_points())
 
         return x,y,z
 
     def get_arrays_direction_space(self):
         if self._sigmaXprime > 0:
-            x = numpy.random.normal(self._direction_space_center[0],self._sigmaXprime,self._number_of_rays)
+            x = numpy.random.normal(self._direction_space_center[0],self._sigmaXprime,self.get_number_of_points())
         else:
-            x = numpy.zeros(self._number_of_rays)
+            x = numpy.zeros(self.get_number_of_points())
 
         if self._sigmaZprime > 0:
-            z = numpy.random.normal(self._direction_space_center[1],self._sigmaZprime,self._number_of_rays)
+            z = numpy.random.normal(self._direction_space_center[1],self._sigmaZprime,self.get_number_of_points())
         else:
-            z = numpy.zeros(self._number_of_rays)
+            z = numpy.zeros(self.get_number_of_points())
         return x,z
 
 
@@ -166,6 +175,10 @@ class SourceGaussian(object):
         spatial and direction coordinates
         :return: xyzxpypzp array
         """
+
+        if self.get_seed() != 0:
+            numpy.random.seed(self.get_seed())
+
         v1 = self.get_volume_real_space()
         v2 = self.get_volume_divergences()
 
@@ -191,7 +204,7 @@ class SourceGaussian(object):
         txt = ""
 
         txt += "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n"
-        txt += "Number of rays: %d \n"%self._number_of_rays
+        txt += "Number of rays: %d \n"%self.get_number_of_points()
         txt += "Gausian source: \n"
         txt += "   Real space: \n"
         txt += "         Horizontal: sigmaX = %5.3f um; FWHM X = %5.3f um\n"%(1e6*self._sigmaX,1e6*f2dot35*self._sigmaX)
