@@ -7,24 +7,22 @@ from shadow4.sources.source_geometrical.probability_distributions import Rectang
 from shadow4.sources.source_geometrical.probability_distributions import Flat2D, Uniform2D, Conical2D
 
 from srxraylib.util.inverse_method_sampler import Sampler1D
+from shadow4.sources.s4_light_source_base import S4LightSourceBase
 
-
-class SourceGeometrical(object):
+class SourceGeometrical(S4LightSourceBase):
     def __init__(self,
+                    name="Undefined",
                     spatial_type="Point",
                     angular_distribution = "Flat",
                     energy_distribution = "Single line",
-                    seed = 123456,
+                    nrays=5000,
+                    seed=1234567,
                  ):
-
-        self.set_spatial_type_by_name(spatial_type)
-        self.set_angular_distribution_by_name(angular_distribution)
-        self.set_energy_distribution_by_name(energy_distribution)
-
-        self._seed = seed
-
-        if seed != 0:
-            numpy.random.seed(seed)
+        super().__init__(name=name, nrays=nrays, seed=seed)
+        self.set_spatial_type_by_name(spatial_type)  # see SourceGeometrical.spatial_type_list()
+        self.set_angular_distribution_by_name(angular_distribution) # see SourceGeometrical.angular_distribution_list()
+        self.set_energy_distribution_by_name(energy_distribution) # see SourceGeometrical.energy_distribution_list()
+        self.set_polarization(polarization_degree=1.0, phase_diff=0.0, coherent_beam=0)
 
 
     #
@@ -85,7 +83,7 @@ class SourceGeometrical(object):
          # 		  Available options are: flat(1),uniform(2),
          # 		  gaussian(3), synchrotron(4), conical(5), exact
          # 		  synchrotron(6).
-        return ["Flat","Uniform","Gaussian","Conical"]
+        return ["Flat","Uniform","Gaussian","Conical","Collimated"]
 
         # cone_max	=  0.0000000000000000E+00 - for fdistr=5; maximum half
         # 					    divergence.
@@ -110,10 +108,19 @@ class SourceGeometrical(object):
             self.set_angular_distribution_gaussian()
         elif name == "Conical":
             self.set_angular_distribution_conical()
+        elif name == "Collimated":
+            self.set_angular_distribution_collimated()
         else:
             raise Exception("Wrong angular distribution: %s"%name)
 
 
+    def set_angular_distribution_collimated(self,):
+        self.angular_distribution = "Flat"
+        self.__hdiv1 = 0.0
+        self.__hdiv2 = 0.0
+        self.__vdiv1 = 0.0
+        self.__vdiv2 = 0.0
+        self.__fdist = 1
 
     # WARNING: in shadow4 limits are signed!!!!
     def set_angular_distribution_flat(self,hdiv1=-5e-6,hdiv2=5e-6,vdiv1=-0.5e-6,vdiv2=0.5e-6):
@@ -145,6 +152,14 @@ class SourceGeometrical(object):
         self.__cone_min = cone_min
         self.__fdist = 5
 
+    def set_polarization(self,
+                         polarization_degree=1, # cos_s / (cos_s + sin_s)
+                         phase_diff=0.000000,   # in rad, 0=linear, pi/2=elliptical/right
+                         coherent_beam=0,       # 0=No (random phase s: col 14)  1=Yes (zero s: col 14)
+                         ):
+        self.__pol_deg = polarization_degree
+        self.__pol_angle = phase_diff
+        self.__f_foher = coherent_beam
     #
     # energy distribution
     #
@@ -273,11 +288,16 @@ class SourceGeometrical(object):
         rays[:,11] = numpy.arange(N) + 1          # index
         return rays
 
-    def calculate_beam(self,N=5000,POL_DEG=1.0,POL_ANGLE=0.0,F_COHER=False):
-        rays = self.calculate_rays(N=N, POL_DEG=POL_DEG, POL_ANGLE=POL_ANGLE, F_COHER=F_COHER)
+    def calculate_beam(self):
+        rays = self.calculate_rays()
         return Beam.initialize_from_array(rays)
 
-    def calculate_rays(self,N=5000,POL_DEG=1.0,POL_ANGLE=0.0,F_COHER=False):
+    def calculate_rays(self):
+
+        if self.get_seed() != 0:
+            numpy.random.seed(self.get_seed())
+
+        N = self.get_nrays()
 
         rays = self._sample_rays_default(N)
 
@@ -349,7 +369,7 @@ class SourceGeometrical(object):
             if self.__f_phot == 0:
                 rays[:,10] = self._energy_to_wavenumber(self.__ph[0])
             else:
-                rays[:,10] = self._wavelength_to_wavenumber(self.__ph[0])
+                rays[:,10] = self._wavelength_to_wavenumber(self.__ph[0] * 1e-10)
         elif self.energy_distribution == "Several lines":
             values = numpy.array(self.__ph)
             n_test =   (numpy.random.random(N) * values.size).astype(int)
@@ -357,7 +377,7 @@ class SourceGeometrical(object):
             if self.__f_phot == 0:
                 rays[:,10] = self._energy_to_wavenumber(sampled_values)
             else:
-                rays[:,10] = self._wavelength_to_wavenumber(sampled_values)
+                rays[:,10] = self._wavelength_to_wavenumber(sampled_values * 1e-10)
         elif self.energy_distribution == "Relative intensities":
             values = numpy.array(self.__ph)
             relative_intensities = numpy.array(self.__rl)
@@ -392,19 +412,19 @@ class SourceGeometrical(object):
             if self.__f_phot == 0:
                 rays[:,10] = self._energy_to_wavenumber(sampled_values)
             else:
-                rays[:,10] = self._wavelength_to_wavenumber(sampled_values)
+                rays[:,10] = self._wavelength_to_wavenumber(sampled_values * 1e-10)
         elif self.energy_distribution == "Uniform":
             sampled_values = self.__ph[0] + (self.__ph[1]-self.__ph[0]) * numpy.random.rand(N)
             if self.__f_phot == 0:
                 rays[:,10] = self._energy_to_wavenumber(sampled_values)
             else:
-                rays[:,10] = self._wavelength_to_wavenumber(sampled_values)
+                rays[:,10] = self._wavelength_to_wavenumber(sampled_values * 1e-10)
         elif self.energy_distribution == "Gaussian":
             sampled_values = numpy.random.normal(loc=self.__ph[0], scale=self.__ph[1], size=N)
             if self.__f_phot == 0:
                 rays[:,10] = self._energy_to_wavenumber(sampled_values)
             else:
-                rays[:,10] = self._wavelength_to_wavenumber(sampled_values)
+                rays[:,10] = self._wavelength_to_wavenumber(sampled_values * 1e-10)
         elif self.energy_distribution == "User defined":
             sampler = Sampler1D(self.__ph_spectrum_ordinates,self.__ph_spectrum_abscissas)
             sampled_values = sampler.get_n_sampled_points(N)
@@ -414,7 +434,7 @@ class SourceGeometrical(object):
             if self.__f_phot == 0:
                 rays[:,10] = self._energy_to_wavenumber(sampled_values)
             else:
-                rays[:,10] = self._wavelength_to_wavenumber(sampled_values)
+                rays[:,10] = self._wavelength_to_wavenumber(sampled_values * 1e-10)
         else:
             raise Exception("Bad value of energy_distribution")
 
@@ -458,12 +478,12 @@ class SourceGeometrical(object):
         # obtain polarization for each ray (interpolation)
         #
 
-        DENOM = numpy.sqrt(1.0 - 2.0 * POL_DEG + 2.0 * POL_DEG ** 2)
-        AX = POL_DEG / DENOM
+        DENOM = numpy.sqrt(1.0 - 2.0 * self.__pol_deg + 2.0 * self.__pol_deg ** 2)
+        AX = self.__pol_deg / DENOM
         for i in range(3):
             A_VEC[:, i] *= AX
 
-        AZ = (1.0 - POL_DEG) / DENOM
+        AZ = (1.0 - self.__pol_deg) / DENOM
         for i in range(3):
             AP_VEC[:, i] *= AZ
 
@@ -477,12 +497,12 @@ class SourceGeometrical(object):
 
         #
 
-        if F_COHER == 1:
+        if self.__f_foher == 1:
             PHASEX = 0.0
         else:
             PHASEX = numpy.random.random(N) * 2 * numpy.pi
 
-        PHASEZ = PHASEX + POL_ANGLE
+        PHASEZ = PHASEX + self.__pol_angle
 
         rays[:, 13] = PHASEX
         rays[:, 14] = PHASEZ
@@ -513,11 +533,94 @@ class SourceGeometrical(object):
             u_norm[:,i] = uu
         return u / u_norm
 
-    def get_beam(self, N=5000, POL_DEG=1.0, POL_ANGLE=0.0, F_COHER=False):
-
-        rays =  self.calculate_rays(N=N,POL_DEG=POL_DEG,POL_ANGLE=POL_ANGLE,F_COHER=F_COHER)
+    def get_beam(self):
+        rays =  self.calculate_rays()
         return Beam.initialize_from_array(rays)
 
+    def to_python_code(self):
+
+        txt = ""
+
+        txt += "\n#\n#\n#"
+
+        txt += "\nfrom shadow4.sources.source_geometrical.source_geometrical import SourceGeometrical"
+
+        txt += "\nlight_source = SourceGeometrical(name='%s', nrays=%d, seed=%d)" % \
+               (self.get_name(), self.get_nrays(), self.get_seed())
+
+        # spatial type
+        if self.__fsour == 0:  # point
+            txt += "\nlight_source.set_spatial_type_point()"
+        elif self.__fsour == 1:  # rectangle
+            txt += "\nlight_source.set_spatial_type_rectangle(width=%f,height=%f)" % \
+                   (self.__wxsou, self.__wzsou)
+        elif self.__fsour == 2:  # ellipse
+            txt += "\nlight_source.set_spatial_type_ellipse(width=%f,height=%f)" % \
+                   (self.__wxsou, self.__wzsou)
+        elif self.__fsour == 3:  # Gaussian
+            txt += "\nlight_source.set_spatial_type_gaussian(sigma_h=%s,sigma_v=%f)" % \
+                   (self.__sigmax, self.__sigdiz)
+
+
+        # divergence
+        if self.__fdist == 1:  # flat
+            txt += "\nlight_source.set_angular_distribution_flat(hdiv1=%f,hdiv2=%f,vdiv1=%f,vdiv2=%f)" % \
+                   (self.__hdiv1, self.__hdiv2, self.__vdiv1, self.__vdiv2)
+        elif self.__fdist == 2:  # Uniform
+            txt += "\nlight_source.set_angular_distribution_uniform(hdiv1=%f,hdiv2=%f,vdiv1=%f,vdiv2=%f)" % \
+                   (self.__hdiv1, self.__hdiv2, self.__vdiv1, self.__vdiv2)
+
+        elif self.angular_distribution == 3:  # Gaussian
+            txt += "\nlight_source.set_angular_distribution_gaussian(sigdix=%f,sigdiz=%f)" % \
+                   (self.__sigdix, self.__sigdiz)
+        elif self.__fdist == 4:  # cone
+            txt += "\nlight_source.set_angular_distribution_conical(cone_max=%f,cone_min=%f" % \
+                   (self.__cone_max, self.__cone_min)
+        elif self.__fdist == 5:  # Zero (collimated) - New in shadow4
+            txt += "\nlight_source.set_angular_distribution_collimated()"
+
+
+        # energy
+        unit = ['eV', 'A'][self.__f_phot]
+
+        if self.__f_color == 1:  # "Single line":
+            txt += "\nlight_source.set_energy_distribution_singleline(%f, unit='%s')" % \
+                   (self.__ph[0], unit)
+        elif self.__f_color == 2:  # "Several lines":
+            nlines = (numpy.array(self.__ph)).size
+            ff = "["
+            for i in range(nlines):
+                ff += "%f," % self.__ph[i]
+            ff += "]"
+            txt += "\nlight_source.set_energy_distribution_severallines(values=%s, unit='%s')" % (ff, unit)
+        elif self.__f_color == 3:  # "Uniform":
+            txt += "\nlight_source.set_energy_distribution_uniform(value_min=%f, value_max=%f, unit='%s')" % \
+                   (self.__ph[0], self.__ph[1], unit)
+        elif self.__f_color == 4:  # "Relative intensities":
+            nlines = (numpy.array(self.__ph)).size
+            ff = "["
+            ww = "["
+            for i in range(nlines):
+                ff += "%f," % self.__ph[i]
+                ww += "%f," % self.__rl[i]
+            ff += "]"
+            ww += "]"
+            txt += "\nlight_source.set_energy_distribution_relativeintensities(values=%s, weights=%s, unit='%s')" % \
+                   (ff, ww, unit)
+        elif self.__f_color == 5:  # "Gaussian":
+            txt += "\nlight_source.set_energy_distribution_gaussian(center=%f, sigma=%f, unit='%s')" % \
+                (self.__ph[0], self.__ph[1], unit)
+        elif self.__f_color == 6:  # "User defined":
+            # a = numpy.loadtxt(self.user_defined_file)
+            txt += "\nlight_source.set_energy_distribution_userdefined() #### TODO: COMPLETE" 
+
+        #polarization/coherence
+        txt += "\nlight_source.set_polarization(polarization_degree=%f, phase_diff=%f, coherent_beam=%s)" % \
+               (self.__pol_deg, self.__pol_angle, self.__f_foher)
+
+        txt += "\nbeam = light_source.get_beam()"
+
+        return txt
 if __name__ == "__main__":
     pass
 
