@@ -94,10 +94,18 @@ def sync_f_sigma_and_pi(rAngle, rEnergy):
 
 class S4WigglerLightSource(S4LightSource):
 
-    def __init__(self, name="Undefined", electron_beam=None, magnetic_structure=None):
+    def __init__(self,
+                 name="Undefined",
+                 electron_beam=None,
+                 magnetic_structure=None,
+                 nrays=5000,
+                 seed=12345,
+                 ):
         super().__init__(name,
                          electron_beam=electron_beam if not electron_beam is None else S4ElectronBeam(),
-                         magnetic_structure=magnetic_structure if not magnetic_structure is None else S4Wiggler())
+                         magnetic_structure=magnetic_structure if not magnetic_structure is None else S4Wiggler(),
+                         nrays=nrays,
+                         seed=seed)
 
         # results of calculations
         self.__result_trajectory = None
@@ -174,7 +182,6 @@ class S4WigglerLightSource(S4LightSource):
         # calculate cdf and write file for Shadow/Source
         #
 
-        print(">>>>>>>>>>>>>>>>>>>>  wiggler._EMIN,wiggler._EMAX,wiggler._NG_E",wiggler._EMIN,wiggler._EMAX,wiggler._NG_E)
         self.__result_cdf = wiggler_cdf(self.__result_trajectory,
                                         enerMin=wiggler._EMIN,
                                         enerMax=wiggler._EMAX,
@@ -183,7 +190,7 @@ class S4WigglerLightSource(S4LightSource):
                                         elliptical=False)
 
 
-    def __calculate_rays(self,user_unit_to_m=1.0,F_COHER=0,NRAYS=5000,SEED=123456,EPSI_DX=0.0,EPSI_DZ=0.0,
+    def __calculate_rays(self,user_unit_to_m=1.0,F_COHER=0,EPSI_DX=0.0,EPSI_DZ=0.0,
                        psi_interval_in_units_one_over_gamma=None,
                        psi_interval_number_of_points=1001,
                        verbose=True):
@@ -194,6 +201,9 @@ class S4WigglerLightSource(S4LightSource):
         :return: rays, a numpy.array((npoits,18))
         """
 
+
+
+
         if self.__result_cdf is None:
             self.__calculate_radiation()
 
@@ -206,17 +216,19 @@ class S4WigglerLightSource(S4LightSource):
         syned_electron_beam = self.get_electron_beam()
 
 
-        sampled_photon_energy,sampled_theta,sampled_phi = self._sample_photon_energy_theta_and_phi(NRAYS)
+        sampled_photon_energy,sampled_theta,sampled_phi = self._sample_photon_energy_theta_and_phi()
 
         if verbose:
             print(">>> sampled sampled_photon_energy,sampled_theta,sampled_phi:  ",sampled_photon_energy,sampled_theta,sampled_phi)
 
-        if SEED != 0:
-            numpy.random.seed(SEED)
+        if self.get_seed() != 0:
+            numpy.random.seed(self.get_seed())
 
 
         sigmas = syned_electron_beam.get_sigmas_all()
 
+        NRAYS = self.get_nrays()
+
         rays = numpy.zeros((NRAYS,18))
 
         #
@@ -830,7 +842,7 @@ class S4WigglerLightSource(S4LightSource):
             u_norm[:,i] = uu
         return u / u_norm
 
-    def _sample_photon_energy_theta_and_phi(self,NRAYS):
+    def _sample_photon_energy_theta_and_phi(self):
 
         #
         # sample divergences
@@ -840,7 +852,7 @@ class S4WigglerLightSource(S4LightSource):
     ############################################################################
     #
     ############################################################################
-    def get_beam(self, NRAYS=5000,SEED=123456):
+    def get_beam(self):
 
         user_unit_to_m = 1.0
         F_COHER = 0
@@ -853,8 +865,6 @@ class S4WigglerLightSource(S4LightSource):
         return Beam.initialize_from_array(self.__calculate_rays(
             user_unit_to_m=user_unit_to_m,
             F_COHER=F_COHER,
-            NRAYS=NRAYS,
-            SEED=SEED,
             EPSI_DX=EPSI_DX,
             EPSI_DZ=EPSI_DZ,
             psi_interval_in_units_one_over_gamma=psi_interval_in_units_one_over_gamma,
@@ -913,11 +923,12 @@ class S4WigglerLightSource(S4LightSource):
             script += "\n\n#Error retrieving magnetic structure code"
 
         script += "\n\n\n#light source\nfrom shadow4.sources.wiggler.s4_wiggler_light_source import S4WigglerLightSource"
-        script += "\nlight_source = S4WigglerLightSource(name='%s', electron_beam=electron_beam, magnetic_structure=source)" % \
-                                                          (self.get_name())
-
-        script += "\n\n\n#beamline\nfrom shadow4.beamline.s4_beamline import S4Beamline"
-        script += "\nbeamline = S4Beamline(light_source=light_source)"
+        script += "\nlight_source = S4WigglerLightSource(name='%s',electron_beam=electron_beam,magnetic_structure=source,nrays=%d,seed=%s)" % \
+                                                          (self.get_name(),self.get_nrays(),self.get_seed())
+        #
+        # script += "\n\n\n#beamline\nfrom shadow4.beamline.s4_beamline import S4Beamline"
+        # script += "\nbeamline = S4Beamline(light_source=light_source)"
+        script += "\nbeam = light_source.get_beam()"
         return script
 if __name__ == "__main__":
     from srxraylib.plot.gol import plot_scatter, set_qt
@@ -973,12 +984,13 @@ if __name__ == "__main__":
 
     # print(w.info())
 
-    ls = S4WigglerLightSource(name="Undefined", electron_beam=electron_beam, magnetic_structure=w)
+    ls = S4WigglerLightSource(name="Undefined", electron_beam=electron_beam, magnetic_structure=w,
+                              nrays=NRAYS)
 
     print(ls.info())
 
 
-    beam = ls.get_beam(NRAYS=NRAYS)
+    beam = ls.get_beam()
 
     rays = beam.rays
 
